@@ -11,20 +11,23 @@ from require.storage import OptimizedFilesMixin
 
 class GzipFixS3BotoStorageMixin(object):
     
+    # Decompresses previously compressed content, essential for correct hash calculation.
     def _open(self, name, mode="rb"):
+        """Opens the given file."""
         file = super(GzipFixS3BotoStorageMixin, self)._open(name, mode)
-        if self.gzip:
-            file = GzipFile(mode=mode, compresslevel=6, fileobj=file)
-            file.size = len(file.read())
+        if file.key.content_encoding == "gzip":
+            file = GzipFile(mode=mode, compresslevel=9, fileobj=file)
+            file_size = len(file.read())
             file.seek(0)
             file = File(file, name=name)
+            file.size = file_size
         return file
     
     # Patch for bug in django-storages with compressed content.
     def _compress_content(self, content):
         """Gzip a given string."""
         zbuf = StringIO()
-        zfile = GzipFile(mode='wb', compresslevel=6, fileobj=zbuf)
+        zfile = GzipFile(mode='wb', compresslevel=9, fileobj=zbuf)
         zfile.write(content.read())
         zfile.close()
         zbuf.seek(0) # i was missing!
